@@ -1,10 +1,10 @@
 import networkx as nx
 # import pygraphviz
 import ast
-from astgraph import AstVisitor
+from GeneratorOfFibAST.astgraph import AstVisitor
 import os
 
-with open("fib.py", 'r') as sourse:
+with open("src/GeneratorOfFibAST/fib.py", 'r') as sourse:
     tree = ast.parse(sourse.read())
 
 # делаем гарф
